summaryrefslogtreecommitdiff
path: root/functions
diff options
context:
space:
mode:
Diffstat (limited to 'functions')
-rwxr-xr-xfunctions/defaults.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/functions/defaults.sh b/functions/defaults.sh
index feabb504b..906bf2ce3 100755
--- a/functions/defaults.sh
+++ b/functions/defaults.sh
@@ -929,7 +929,7 @@ Set_defaults ()
_LB_BOOTAPPEND_PRESEED="file=/cdrom/install/${LB_DEBIAN_INSTALLER_PRESEEDFILE}"
;;
- usb*)
+ hdd*)
case "${LB_MODE}" in
ubuntu|kubuntu)
if [ "${LB_DEBIAN_INSTALLER}" = "live" ]
@@ -1207,8 +1207,8 @@ Check_defaults ()
fi
case "${LB_BINARY_IMAGES}" in
- usb*)
- # grub or yaboot + usb
+ hdd*)
+ # grub or yaboot + hdd
case "${LB_BOOTLOADER}" in
grub|yaboot)
Echo_error "You have selected a combination of bootloader and image type that is currently not supported by live-build. Please use either another bootloader or a different image type."